# 2023-02-22 - Merkle Orchard V2

Patch deployment of the `MerkleOrchard`, to distribute tokens via Merkle Trees.
This release supersedes [Merkle Orchard V1](../deprecated/20211012-merkle-orchard/), fixing the double-claim issue described in [this report](https://medium.com/immunefi/balancer-logic-error-bugfix-review-74f5edca8b1a).

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [Polygon mainnet addresses](./output/polygon.json)
- [Arbitrum mainnet addresses](./output/arbitrum.json)
- [Goerli testnet addresses](./output/goerli.json)
- [`MerkleOrchard` artifact](./artifact/MerkleOrchard.json)
